@@ -333,9 +333,9 @@ func (o *MirrorOptions) handleSignatures(context context.Context, signaturesByDi
 				if o.Overwrite {
 					// An error is returned if the configmap does not exist in which case we will
 					// attempt to create the manifest.
-					if _, err := client.Get(cmData.Name, metav1.GetOptions{}); err == nil {
+					if _, err := client.Get(context, cmData.Name, metav1.GetOptions{}); err == nil {
 						create = false
-						if _, err := client.Update(cmData); err != nil {
+						if _, err := client.Update(context, cmData, metav1.UpdateOptions{}); err != nil {
 							return fmt.Errorf("updating configmap %s: %v", cmData.Name, err)
 						} else {
 							fmt.Fprintf(o.Out, "configmap/%s configured\n", cmData.Name)
@@ -343,7 +343,7 @@ func (o *MirrorOptions) handleSignatures(context context.Context, signaturesByDi
 					}
 				}
 				if create {
-					if _, err := client.Create(cmData); err != nil {
+					if _, err := client.Create(context, cmData, metav1.CreateOptions{}); err != nil {
 						return fmt.Errorf("creating configmap %s: %v", cmData.Name, err)
 					} else {
 						fmt.Fprintf(o.Out, "configmap/%s created\n", cmData.Name)
@@ -683,7 +683,7 @@ func (o *MirrorOptions) Run() error {
 					Body(isi).
 					// this instructs the api server to allow our request to take up to an hour - chosen as a high boundary
 					Timeout(3 * time.Minute).
-					Do().
+					Do(context.TODO()).
 					Into(result); err != nil {
 					return err
 				}
